UwU

example:
```py
from ab5 import vgratient

logo = '''
   __  __         __  __
  / / / /      __/ / / /
 / / / / | /| / / / / / 
/ /_/ /| |/ |/ / /_/ /  
\____/ |__/|__/\____/   
                        '''

# color in decemal rgb [red,green,blue] (max 255 min 0)
start_color=[0,223,50]
end_color=[0,25,222]

print(vgratient(logo,start_color,end_color))
```

<p align="center">
  <img src="https://cdn.discordapp.com/attachments/790977863847116830/980557615413219388/unknown.png">
</p>